/*
** Module   : ResultListHandler.java
** Abstract : Defines some common API for Query and Browse widget
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ------------------------------- Description --------------------------------
** 001 OM  20130320 Created initial version. Declares only two basic methods.
** 002 EVL 20130911 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.persist;

import com.goldencode.p2j.util.logical;
import com.goldencode.p2j.util.LegacyMethod;

/**
 * Declares the pair methods for handling result-lists
 * CREATE-RESULT-LIST-ENTRY and DELETE-RESULT-LIST-ENTRY.
 *
 * @author om
 */
public interface ResultListHandler
{
   /**
    * This will creates an entry in the result list for the current row.  This implements the
    * 4GL CREATE-RESULT-LIST-ENTRY() method.
    * 
    * @return  true on success.
    */
   @LegacyMethod(name = "CREATE-RESULT-LIST-ENTRY")
   public logical createResultListEntry();

   /**
    * This will delete the current row in the query's results.  This implements the
    * 4GL DELETE-RESULT-LIST-ENTRY() method.
    * 
    * @return  true on success.
    */
   @LegacyMethod(name = "DELETE-RESULT-LIST-ENTRY")
   public logical deleteResultListEntry();
}
